@@ -2,16 +2,14 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-19 11:33:16
-:LastEditTime: 2021-02-24 15:58:07
+:LastEditTime: 2021-04-15 14:48:26
 :LastEditors: HuangJingCan
 :description: 用户处理
 """
 from seven_cloudapp.handlers.top_base import *
-from seven_cloudapp.libs.customize.seven import *
 
 from seven_cloudapp.models.behavior_model import *
 from seven_cloudapp.models.seven_model import PageInfo
-
 from seven_cloudapp.models.db_models.user.user_info_model import *
 from seven_cloudapp.models.db_models.app.app_info_model import *
 from seven_cloudapp.models.db_models.pay.pay_order_model import *
@@ -23,11 +21,13 @@ from seven_cloudapp.models.db_models.ip.ip_series_model import *
 
 from seven_cloudapp.handlers.client.user import UserHandler
 from seven_cloudapp.handlers.client.user import LoginHandler
+from seven_cloudapp.handlers.client.user import GetIntegralListHandler
+from seven_cloudapp.handlers.client.user import GetUserDetailHandler
 
-from seven_cloudapp_ppmt.models.db_models.act.act_info_model import *
 from seven_cloudapp_ppmt.models.db_models.act.act_prize_model import *
 from seven_cloudapp_ppmt.models.db_models.machine.machine_info_model import *
 from seven_cloudapp_ppmt.models.db_models.prize.prize_roster_model import *
+from seven_cloudapp_ppmt.models.db_models.act.act_info_model import *
 
 
 class SyncPayOrderHandler(TopBaseHandler):
@@ -47,31 +47,31 @@ class SyncPayOrderHandler(TopBaseHandler):
         app_id = self.get_taobao_param().source_app_id
 
         access_token = ""
-        app_info = AppInfoModel().get_entity("app_id=%s", params=app_id)
+        app_info = AppInfoModel(context=self).get_entity("app_id=%s", params=app_id)
         if app_info:
             access_token = app_info.access_token
-        user_info_model = UserInfoModel()
+        user_info_model = UserInfoModel(context=self)
         user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
         if not user_info:
             return self.reponse_json_error('NoUser', '对不起，用户不存在')
-        act_info_model = ActInfoModel()
+        act_info_model = ActInfoModel(context=self)
         act_info = act_info_model.get_entity('id=%s', params=[act_id])
         if not act_info:
             return self.reponse_json_error('NoAct', '对不起，活动不存在')
 
         # 获取订单
         order_data = self.get_taobao_order(open_id, access_token)
-        # self.logger_info.info(str(order_data) + "【订单列表】")
+        # self.logging_link_info(str(order_data) + "【订单列表】")
 
         #获取所有盲盒配置
-        machine_info_model = MachineInfoModel()
+        machine_info_model = MachineInfoModel(context=self)
         machine_config_list = machine_info_model.get_list("act_id=%s", params=[act_id])
 
         #获取价格档位配置
-        price_gear_model = PriceGearModel()
+        price_gear_model = PriceGearModel(context=self)
         price_gear_list = price_gear_model.get_list("act_id=%s", params=[act_id])
 
-        pay_order_model = PayOrderModel()
+        pay_order_model = PayOrderModel(context=self)
         pay_order_list = pay_order_model.get_list("open_id=%s and act_id=%s", order_by="id desc", params=[open_id, act_id])
 
         pay_order_id_list = []
@@ -142,7 +142,7 @@ class SyncPayOrderHandler(TopBaseHandler):
                         #获得次数
                         prize_count = int(order["num"])
 
-                        gear_value_model = GearValueModel()
+                        gear_value_model = GearValueModel(context=self)
                         gear_value = gear_value_model.get_entity("act_id=%s and price_gears_id=%s and open_id=%s", params=[act_id, now_price_gear_config.id, open_id])
                         if not gear_value:
                             gear_value = GearValue()
@@ -173,7 +173,7 @@ class SyncPayOrderHandler(TopBaseHandler):
                         user_info_dict["machine_value_list"] = gear_value_list_dict
 
                         #添加记录
-                        coin_order_model = CoinOrderModel()
+                        coin_order_model = CoinOrderModel(context=self)
                         coin_order = CoinOrder()
                         coin_order.open_id = open_id
                         coin_order.app_id = app_id
@@ -196,7 +196,7 @@ class SyncPayOrderHandler(TopBaseHandler):
                     #结束
 
         except Exception as ex:
-            self.logger_info.info(str(all_sub_order_list) + "【订单列表】" + str(ex))
+            self.logging_link_info(str(all_sub_order_list) + "【订单列表】" + str(ex))
             return self.reponse_json_error('Error', '获取订单失败')
 
         if user_info.user_state == 0 and act_info.is_black == 1 and act_info.refund_count > 0:
@@ -218,14 +218,14 @@ class SyncPayOrderHandler(TopBaseHandler):
             result["total_pay_num"] = total_pay_num
             result["total_pay_prize"] = total_pay_prize
 
-            behavior_model = BehaviorModel()
+            behavior_model = BehaviorModel(context=self)
             behavior_model.report_behavior_log(app_id, act_id, open_id, act_info.owner_open_id, 'PayMoneyCount', decimal.Decimal(total_pay_prize))
             behavior_model.report_behavior_log(app_id, act_id, open_id, act_info.owner_open_id, 'PayerCount', 1)
             behavior_model.report_behavior_log(app_id, act_id, open_id, act_info.owner_open_id, 'PayCount', total_pay_num)
 
-            self.reponse_json_success(result)
+            return self.reponse_json_success(result)
         else:
-            self.reponse_json_success()
+            return self.reponse_json_success()
 
 
 class PrizeOrderHandler(SevenBaseHandler):
@@ -248,9 +248,9 @@ class PrizeOrderHandler(SevenBaseHandler):
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
 
-        prize_order_model = PrizeOrderModel()
-        prize_roster_model = PrizeRosterModel()
-        ip_series_model = IpSeriesModel()
+        prize_order_model = PrizeOrderModel(context=self)
+        prize_roster_model = PrizeRosterModel(context=self)
+        ip_series_model = IpSeriesModel(context=self)
         prize_order_list_dict, total = prize_order_model.get_dict_page_list("*", page_index, page_size, "open_id=%s and act_id=%s", "", "create_date desc", [open_id, act_id])
         if prize_order_list_dict:
             prize_order_id_list = [str(i["id"]) for i in prize_order_list_dict]
@@ -273,7 +273,7 @@ class PrizeOrderHandler(SevenBaseHandler):
 
         page_info = PageInfo(page_index, page_size, total, prize_order_list_dict)
 
-        self.reponse_json_success(page_info)
+        return self.reponse_json_success(page_info)
 
 
 class GetNumByPriceGearsListHandler(SevenBaseHandler):
@@ -294,10 +294,10 @@ class GetNumByPriceGearsListHandler(SevenBaseHandler):
         open_id = self.get_taobao_param().open_id
         act_id = int(self.get_param("act_id", 0))
 
-        price_gear_model = PriceGearModel()
-        ip_series_model = IpSeriesModel()
-        gear_value_model = GearValueModel()
-        machine_info_model = MachineInfoModel()
+        price_gear_model = PriceGearModel(context=self)
+        ip_series_model = IpSeriesModel(context=self)
+        gear_value_model = GearValueModel(context=self)
+        machine_info_model = MachineInfoModel(context=self)
         result_price_gear_list = []
         price_gear_list = price_gear_model.get_dict_list("act_id=%s and is_del=0", params=[act_id])
         if len(price_gear_list) > 0:
@@ -319,7 +319,7 @@ class GetNumByPriceGearsListHandler(SevenBaseHandler):
                     price_gear["gear_value"] = gear_value_list_filter[0]["current_value"]
                 result_price_gear_list.append(price_gear)
 
-        self.reponse_json_success(result_price_gear_list)
+        return self.reponse_json_success(result_price_gear_list)
 
 
 class GetUnpackNumHandler(SevenBaseHandler):
@@ -338,9 +338,9 @@ class GetUnpackNumHandler(SevenBaseHandler):
         machine_id = int(self.get_param("machine_id", 0))
         act_id = int(self.get_param("act_id", 0))
 
-        gear_value_model = GearValueModel()
-        price_gear_model = PriceGearModel()
-        machine_info_model = MachineInfoModel()
+        gear_value_model = GearValueModel(context=self)
+        price_gear_model = PriceGearModel(context=self)
+        machine_info_model = MachineInfoModel(context=self)
         result_info = {}
         result_info["gear_value"] = 0
         machine_info = machine_info_model.get_entity("id=%s and is_release=1", params=[machine_id])
@@ -356,7 +356,7 @@ class GetUnpackNumHandler(SevenBaseHandler):
                     if gear_value:
                         result_info["gear_value"] = int(gear_value.current_value)
 
-        self.reponse_json_success(result_info)
+        return self.reponse_json_success(result_info)
 
 
 class PrizeOrderBySeriesHandler(SevenBaseHandler):
@@ -381,15 +381,15 @@ class PrizeOrderBySeriesHandler(SevenBaseHandler):
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
 
-        prize_order_model = PrizeOrderModel()
-        prize_roster_model = PrizeRosterModel()
-        ip_series_model = IpSeriesModel()
+        prize_order_model = PrizeOrderModel(context=self)
+        prize_roster_model = PrizeRosterModel(context=self)
+        ip_series_model = IpSeriesModel(context=self)
         prize_roster_list_dict, total = prize_roster_model.get_dict_page_list("*", page_index, page_size, "open_id=%s and act_id=%s and series_id=%s", "", "create_date desc", [open_id, act_id, series_id])
         prize_order_list_dict = []
         if prize_roster_list_dict:
             prize_order_id_list = [str(i["prize_order_id"]) for i in prize_roster_list_dict]
             prize_order_ids = ",".join(prize_order_id_list)
-            prize_order_list_dict = prize_order_model.get_dict_list("id in (" + prize_order_ids + ")")
+            prize_order_list_dict = prize_order_model.get_dict_list("id in (" + prize_order_ids + ")", order_by="create_date desc")
 
             ip_series_list_dict = []
             ip_series_id_list = [str(i["series_id"]) for i in prize_roster_list_dict]
@@ -406,7 +406,7 @@ class PrizeOrderBySeriesHandler(SevenBaseHandler):
 
         page_info = PageInfo(page_index, page_size, total, prize_order_list_dict)
 
-        self.reponse_json_success(page_info)
+        return self.reponse_json_success(page_info)
 
 
 class GetHorseRaceLampListHandler(SevenBaseHandler):
@@ -435,14 +435,14 @@ class GetHorseRaceLampListHandler(SevenBaseHandler):
         else:
             condition = "act_id=%s and machine_id=%s"
             params = [act_id, machine_id]
-        act_prize_list_dict = ActPrizeModel().get_dict_list("act_id=%s and is_prize_notice=0", params=[act_id])
+        act_prize_list_dict = ActPrizeModel(context=self).get_dict_list("act_id=%s and is_prize_notice=0", params=[act_id])
         if act_prize_list_dict:
             prize_id_list = [str(i["id"]) for i in act_prize_list_dict]
             if len(prize_id_list) > 0:
                 prize_ids = ",".join(prize_id_list)
                 condition += " and prize_id not in (" + prize_ids + ")"
         condition += f" and create_date>'{TimeHelper.add_hours_by_format_time(hour=7)}'"
-        prize_roster_model = PrizeRosterModel()
+        prize_roster_model = PrizeRosterModel(context=self)
         page_list = prize_roster_model.get_dict_list(condition, "", "create_date desc", str(page_size), "user_nick,prize_name,tag_id,machine_name", params)
         total = int(len(page_list))
         if total == 0:
@@ -462,17 +462,18 @@ class GetHorseRaceLampListHandler(SevenBaseHandler):
             if machine_id > 0:
                 machine_condition += " and id=%s"
                 machine_params = [act_id, machine_id]
-            machine_info_list = MachineInfoModel().get_list(machine_condition, params=machine_params)
+            machine_info_list = MachineInfoModel(context=self).get_list(machine_condition, params=machine_params)
             if len(machine_info_list) > 0:
                 machine_id_list = [str(i.id) for i in machine_info_list]
                 machine_ids = ",".join(machine_id_list)
                 addNum = page_size - total
                 if machine_id > 0:
-                    false_act_prize_list = ActPrizeModel().get_list("act_id=%s and machine_id=%s and is_prize_notice=1", order_by="probability desc", limit="30", params=[act_id, machine_id])
+                    false_act_prize_list = ActPrizeModel(context=self).get_list("act_id=%s and machine_id=%s and is_prize_notice=1", order_by="probability desc", limit="30", params=[act_id, machine_id])
                 else:
-                    false_act_prize_list = ActPrizeModel().get_list("act_id=%s and machine_id in (" + machine_ids + ") and is_prize_notice=1", order_by="probability desc", limit="30", params=[act_id])
-                if len(false_act_prize_list) > 0:
-                    user_info_list_dict = UserInfoModel().get_dict_list("app_id!=%s and open_id!=%s and user_nick!=''", order_by="RAND()", params=[app_id, open_id], limit=str(addNum))
+                    false_act_prize_list = ActPrizeModel(context=self).get_list("act_id=%s and machine_id in (" + machine_ids + ") and is_prize_notice=1", order_by="probability desc", limit="30", params=[act_id])
+                if len(false_act_prize_list) > 0 and addNum > 0:
+                    now_datetime = TimeHelper.add_hours_by_format_time(hour=-random.randint(0, 1000))
+                    user_info_list_dict = UserInfoModel(context=self).get_dict_list("app_id!=%s and user_nick!='' and create_date>%s", params=[app_id, now_datetime], limit=str(addNum))
                     random_Prize_dict_list = {}
                     for act_prize in false_act_prize_list:
                         random_Prize_dict_list[act_prize.id] = act_prize.probability
@@ -496,4 +497,4 @@ class GetHorseRaceLampListHandler(SevenBaseHandler):
                         prize_roster["machine_name"] = machine_info_filter[0].machine_name if len(machine_info_filter) > 0 else ""
                         page_list.append(prize_roster)
 
-        self.reponse_json_success(page_list)
\ No newline at end of file
+        return self.reponse_json_success(page_list)
\ No newline at end of file
